import { __extends, __spread } from 'tslib';
import { TranslateCompiler } from '@ngx-translate/core';

var phraseAppEditor = false;
function sanitizeConfig(config) {
    config.prefix = config.prefix ? config.prefix : '{{__';
    config.suffix = config.suffix ? config.suffix : '__}}';
    return config;
}
function initializePhraseAppEditor(config) {
    if (phraseAppEditor)
        return;
    phraseAppEditor = true;
    window.PHRASEAPP_ENABLED = config.phraseEnabled;
    window.PHRASEAPP_CONFIG = sanitizeConfig(config);
    if (config.phraseEnabled) {
        var phraseapp = document.createElement('script');
        phraseapp.type = 'text/javascript';
        phraseapp.async = true;
        phraseapp.src = ['https://', 'phraseapp.com/assets/in-context-editor/2.0/app.js?', new Date().getTime()].join('');
        var s = document.getElementsByTagName('script')[0];
        if (s != undefined) {
            s.parentNode.insertBefore(phraseapp, s);
        }
        else {
            document.insertBefore(phraseapp, null);
        }
    }
}
function isPhraseEnabled() {
    return window.PHRASEAPP_ENABLED;
}
function escapeId(id) {
    var config = window.PHRASEAPP_CONFIG;
    return config.prefix + 'phrase_' + id + config.suffix;
}

var PhraseAppCompiler = /** @class */ (function (_super) {
    __extends(PhraseAppCompiler, _super);
    function PhraseAppCompiler() {
        return _super.call(this) || this;
    }
    PhraseAppCompiler.prototype.compile = function (value, lang) {
        if (!isPhraseEnabled()) {
            return value;
        }
        return escapeId(value);
    };
    PhraseAppCompiler.prototype.compileTranslations = function (translations, lang) {
        if (!isPhraseEnabled()) {
            return translations;
        }
        translations = this.flatten(translations);
        var escapedTranslations = {};
        Object.keys(translations).forEach(function (key, _) {
            escapedTranslations[key] = escapeId(key);
        });
        return escapedTranslations;
    };
    PhraseAppCompiler.prototype.flatten = function (object) {
        var separator = '.';
        var isValidObject = function (value) {
            if (value === void 0) { value = {}; }
            if (!value) {
                return false;
            }
            var isArray = Array.isArray(value);
            var isΟbject = Object.prototype.toString.call(value) === '[object Object]';
            var hasKeys = !!Object.keys(value).length;
            return !isArray && isΟbject && hasKeys;
        };
        var walker = function (child, path) {
            if (child === void 0) { child = {}; }
            if (path === void 0) { path = []; }
            return Object.assign.apply(Object, __spread([{}], Object.keys(child).map(function (key) {
                var _a;
                return isValidObject(child[key])
                    ? walker(child[key], path.concat([key]))
                    : (_a = {}, _a[path.concat([key]).join(separator)] = child[key], _a);
            })));
        };
        return Object.assign({}, walker(object));
    };
    return PhraseAppCompiler;
}(TranslateCompiler));

/**
 * Generated bundle index. Do not edit.
 */

export { PhraseAppCompiler, initializePhraseAppEditor };
//# sourceMappingURL=ngx-translate-phraseapp.js.map
